==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/macie2_findings_filter/Macie2FindingsFilterFindingCriteria.java <==
package com.hashicorp.cdktf.providers.aws.macie2_findings_filter;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.737Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.macie2FindingsFilter.Macie2FindingsFilterFindingCriteria")
@software.amazon.jsii.Jsii.Proxy(Macie2FindingsFilterFindingCriteria.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Macie2FindingsFilterFindingCriteria extends software.amazon.jsii.JsiiSerializable {

    /**
     * criterion block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter#criterion Macie2FindingsFilter#criterion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCriterion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Macie2FindingsFilterFindingCriteria}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Macie2FindingsFilterFindingCriteria}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Macie2FindingsFilterFindingCriteria> {
        java.lang.Object criterion;

        /**
         * Sets the value of {@link Macie2FindingsFilterFindingCriteria#getCriterion}
         * @param criterion criterion block.
         *                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter#criterion Macie2FindingsFilter#criterion}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder criterion(com.hashicorp.cdktf.IResolvable criterion) {
            this.criterion = criterion;
            return this;
        }

        /**
         * Sets the value of {@link Macie2FindingsFilterFindingCriteria#getCriterion}
         * @param criterion criterion block.
         *                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter#criterion Macie2FindingsFilter#criterion}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder criterion(java.util.List<? extends com.hashicorp.cdktf.providers.aws.macie2_findings_filter.Macie2FindingsFilterFindingCriteriaCriterion> criterion) {
            this.criterion = criterion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Macie2FindingsFilterFindingCriteria}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Macie2FindingsFilterFindingCriteria build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Macie2FindingsFilterFindingCriteria}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Macie2FindingsFilterFindingCriteria {
        private final java.lang.Object criterion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.criterion = software.amazon.jsii.Kernel.get(this, "criterion", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.criterion = builder.criterion;
        }

        @Override
        public final java.lang.Object getCriterion() {
            return this.criterion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCriterion() != null) {
                data.set("criterion", om.valueToTree(this.getCriterion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.macie2FindingsFilter.Macie2FindingsFilterFindingCriteria"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Macie2FindingsFilterFindingCriteria.Jsii$Proxy that = (Macie2FindingsFilterFindingCriteria.Jsii$Proxy) o;

            return this.criterion != null ? this.criterion.equals(that.criterion) : that.criterion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.criterion != null ? this.criterion.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/macie2_findings_filter/Macie2FindingsFilterFindingCriteria.java <==
package com.hashicorp.cdktf.providers.aws.macie2_findings_filter;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.632Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.macie2FindingsFilter.Macie2FindingsFilterFindingCriteria")
@software.amazon.jsii.Jsii.Proxy(Macie2FindingsFilterFindingCriteria.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface Macie2FindingsFilterFindingCriteria extends software.amazon.jsii.JsiiSerializable {

    /**
     * criterion block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/macie2_findings_filter#criterion Macie2FindingsFilter#criterion}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCriterion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Macie2FindingsFilterFindingCriteria}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Macie2FindingsFilterFindingCriteria}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<Macie2FindingsFilterFindingCriteria> {
        java.lang.Object criterion;

        /**
         * Sets the value of {@link Macie2FindingsFilterFindingCriteria#getCriterion}
         * @param criterion criterion block.
         *                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/macie2_findings_filter#criterion Macie2FindingsFilter#criterion}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder criterion(com.hashicorp.cdktf.IResolvable criterion) {
            this.criterion = criterion;
            return this;
        }

        /**
         * Sets the value of {@link Macie2FindingsFilterFindingCriteria#getCriterion}
         * @param criterion criterion block.
         *                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/macie2_findings_filter#criterion Macie2FindingsFilter#criterion}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder criterion(java.util.List<? extends com.hashicorp.cdktf.providers.aws.macie2_findings_filter.Macie2FindingsFilterFindingCriteriaCriterion> criterion) {
            this.criterion = criterion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Macie2FindingsFilterFindingCriteria}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public Macie2FindingsFilterFindingCriteria build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Macie2FindingsFilterFindingCriteria}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Macie2FindingsFilterFindingCriteria {
        private final java.lang.Object criterion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.criterion = software.amazon.jsii.Kernel.get(this, "criterion", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.criterion = builder.criterion;
        }

        @Override
        public final java.lang.Object getCriterion() {
            return this.criterion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCriterion() != null) {
                data.set("criterion", om.valueToTree(this.getCriterion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.macie2FindingsFilter.Macie2FindingsFilterFindingCriteria"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Macie2FindingsFilterFindingCriteria.Jsii$Proxy that = (Macie2FindingsFilterFindingCriteria.Jsii$Proxy) o;

            return this.criterion != null ? this.criterion.equals(that.criterion) : that.criterion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.criterion != null ? this.criterion.hashCode() : 0;
            return result;
        }
    }
}
